==> spip_4.0.4.orig.tar.xz: plugins-dist/revisions/lang/revisions_pt_br.php <==
<?php
// This is a SPIP language file  --  Ceci est un fichier langue de SPIP
// extrait automatiquement de https://trad.spip.net/tradlang_module/revisions?lang_cible=pt_br
// ** ne pas modifier le fichier **

if (!defined('_ECRIRE_INC_VERSION')) {
	return;
}

$GLOBALS[$GLOBALS['idx_lang']] = array(

	// B
	'bouton_comparer' => 'Ver diferenças',

	// D
	'diff_para_ajoute' => 'Parágrafo incluído',
	'diff_para_deplace' => 'Parágrafo movido',
	'diff_para_supprime' => 'Parágrafo excluído',
	'diff_texte_ajoute' => 'Texto incluído',
	'diff_texte_deplace' => 'Texto movido',
	'diff_texte_supprime' => 'Texto excluído',
	'differences_versions' => 'Diferenças entre versão N<sup>o</sup>@id_version@ e versão N<sup>o</sup>@id_diff@',

	// I
	'icone_restaurer_version' => 'Restaurar a versão N<sup>o</sup>@version@',
	'icone_suivi_revisions' => 'Monitorar revisões',
	'info_1_revision' => '1 revisão',
	'info_aucune_revision' => 'Nenhuma revisão',
	'info_historique' => 'Versões:',
	'info_historique_lien' => 'Exibir o histórico de alterações',
	'info_historique_titre' => 'Acompanhamento de versões',
	'info_nb_revisions' => '@nb@ revisões',

	// L
	'label_choisir_id_version' => 'Selecione as versões que quer comparar',
	'label_config_revisions_objets' => 'Ativar revisões para quais objetos:',

	// M
	'message_valider_recuperer_version' => 'Validar o formulário para retornar a essa versão.',

	// O
	'objet_editorial' => 'objeto',

	// P
	'plugin_update' => 'Atualização do plugin "Revisões" para a versão @version@.',

	// T
	'titre_form_revisions_objets' => 'Ativar revisões',
	'titre_restaurer_version' => 'Restaurar uma versão',
	'titre_revisions' => 'Revisões',

	// V
	'version_deplace_rubrique' => 'Mover de <b>«@from@»</b> para <b>«@to@»</b>.',
	'version_initiale' => 'versão inicial',
	'voir_differences' => 'Ver diferenças',
	'voir_mes_revisions' => 'Minhas revisões',
	'voir_revisions' => 'Ver revisões (@objet@ @id_objet@: @titre@)',
	'voir_toutes_les_revisions' => 'Todas as revisões'
);

==> spip_4.4.3+dfsg.orig.tar.xz: plugins-dist/revisions/lang/revisions_pt_br.php <==
<?php
// This is a SPIP language file  --  Ceci est un fichier langue de SPIP
// extrait automatiquement de https://trad.spip.net/tradlang_module/revisions?lang_cible=pt_br
// ** ne pas modifier le fichier **

return [

	// B
	'bouton_comparer' => 'Ver diferenças',

	// D
	'diff_para_ajoute' => 'Parágrafo incluído',
	'diff_para_deplace' => 'Parágrafo movido',
	'diff_para_supprime' => 'Parágrafo excluído',
	'diff_texte_ajoute' => 'Texto incluído',
	'diff_texte_deplace' => 'Texto movido',
	'diff_texte_supprime' => 'Texto excluído',
	'differences_versions' => 'Diferenças entre versão N<sup>o</sup>@id_version@ e versão N<sup>o</sup>@id_diff@',

	// I
	'icone_restaurer_version' => 'Restaurar a versão N<sup>o</sup>@version@',
	'icone_suivi_revisions' => 'Monitorar revisões',
	'info_1_revision' => '1 revisão',
	'info_aucune_revision' => 'Nenhuma revisão',
	'info_historique' => 'Versões:',
	'info_historique_lien' => 'Exibir o histórico de alterações',
	'info_historique_titre' => 'Acompanhamento de versões',
	'info_nb_revisions' => '@nb@ revisões',

	// L
	'label_choisir_id_version' => 'Selecione as versões que quer comparar',
	'label_config_revisions_objets' => 'Ativar revisões para quais objetos:',

	// M
	'message_valider_recuperer_version' => 'Validar o formulário para retornar a essa versão.',

	// O
	'objet_editorial' => 'objeto',

	// P
	'plugin_update' => 'Atualização do plugin "Revisões" para a versão @version@.',

	// T
	'titre_form_revisions_objets' => 'Ativar revisões',
	'titre_restaurer_version' => 'Restaurar uma versão',
	'titre_revisions' => 'Revisões',

	// V
	'version_deplace_rubrique' => 'Mover de <b>«@from@»</b> para <b>«@to@»</b>.',
	'version_initiale' => 'versão inicial',
	'voir_differences' => 'Ver diferenças',
	'voir_mes_revisions' => 'Minhas revisões',
	'voir_revisions' => 'Ver revisões (@objet@ @id_objet@: @titre@)',
	'voir_toutes_les_revisions' => 'Todas as revisões',
];
